@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001-2002 Zope Foundation and Contributors.
+# Copyright (c) 2001, 2002 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,11 +12,8 @@
 #
 ##############################################################################
 """HTTP Publisher
-
-$Id: http.py 105429 2009-11-02 07:47:51Z ctheune $
 """
 from cStringIO import StringIO
-from zope.authentication.loginpassword import LoginPassword
 from zope.i18n.interfaces import IUserPreferredCharsets
 from zope.i18n.interfaces import IUserPreferredLanguages
 from zope.i18n.locales import locales, LoadLocaleError
@@ -50,6 +47,10 @@ import zope.interface
 # Default Encoding
 ENCODING = 'UTF-8'
 
+# not just text/* but RFC 3023 and */*+xml
+import re
+unicode_mimetypes_re = re.compile(r"^text\/.*$|^.*\/xml.*$|^.*\+xml$")
+
 eventlog = logging.getLogger('eventlog')
 
 class CookieMapper(RequestDataMapper):
@@ -796,13 +797,10 @@ class HTTPResponse(BaseResponse):
         content_type = self.getHeader('content-type')
 
         if isinstance(body, unicode):
-            try:
-                if not content_type.startswith('text/'):
-                    raise ValueError(
-                        'Unicode results must have a text content type.')
-            except AttributeError:
-                    raise ValueError(
-                        'Unicode results must have a text content type.')
+            if not unicode_mimetypes_re.match(content_type):
+                raise ValueError(
+                    'Unicode results must have a text, RFC 3023, or '
+                    '+xml content type.')
 
             major, minor, params = zope.contenttype.parse.parse(content_type)
 
@@ -1037,24 +1035,8 @@ class DirectResult(object):
         return iter(self.body)
 
 
-class BasicAuthAdapter(LoginPassword):
-    """ILoginPassword adapter for handling HTTP Basic authentication"""
-
-    # This was moved from zope.app.security as a part of refactoring process,
-    # see http://mail.zope.org/pipermail/zope-dev/2009-March/035325.html for
-    # the reasoning.
-
-    zope.component.adapts(IHTTPCredentials)
-
-    def __init__(self, request):
-        self.__request = request
-        # TODO base64 decoding should be done here, not in request
-        lpw = request._authUserPW()
-        if lpw is None:
-            login, password = None, None
-        else:
-            login, password = lpw
-        super(BasicAuthAdapter, self).__init__(login, password)
-
-    def needLogin(self, realm):
-        self.__request.unauthorized('basic realm="%s"' % realm)
+# BBB
+try:
+    from zope.login.http import BasicAuthAdapter
+except ImportError:
+    pass
